#
# spec file for package python-sorl-thumbnail
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-sorl-thumbnail
Version:        12.10.0
Release:        1.1
Summary:        Thumbnails for Django
License:        BSD-3-Clause
URL:            https://github.com/jazzband/sorl-thumbnail
Source:         https://files.pythonhosted.org/packages/source/s/sorl-thumbnail/sorl-thumbnail-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module django-codemod}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  lsof
BuildRequires:  psmisc
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 3.2
Recommends:     ImageMagick
Recommends:     python-dbm
Suggests:       python-Wand
Suggests:       python-ImageMagick
Suggests:       vips-tools
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django >= 3.2}
BuildRequires:  %{python_module Wand}
BuildRequires:  %{python_module boto if python-base < 3.10}
BuildRequires:  %{python_module dbm}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module redis}
BuildRequires:  ImageMagick
BuildRequires:  redis
BuildRequires:  vips-tools
# /SECTION
%python_subpackages

%description
Thumbnails for Django.

Features at a glance
---------------------
- Storage support
- Pluggable Engine support (PIL, pgmagick)
- Pluggable Key Value Store support (redis, cached db)
- Pluggable Backend support
- Admin integration with possibility to delete
- Dummy generation
- Flexible, simple syntax, generates no html
- ImageField for model that deletes thumbnails
- CSS style cropping options
- Margin calculation for vertical positioning

%prep
%setup -q -n sorl-thumbnail-%{version}

djcodemod run --removed-in 4.0 tests/*/urls.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8

PYTHONPATH=.
export DJANGO_SETTINGS_MODULE=tests.settings.pil
# TestDescriptors: gh#jazzband/sorl-thumbnail#673
# TemplateTestCaseB & test_image_file_deserialize: three tests use online resources
skip_tests="TestDescriptors or test_image_file_deserialize or test_image_with_orientation or (TemplateTestCaseB and (test_portrait or test_url))"
%pytest -rs -k "not ($skip_tests)"
export DJANGO_SETTINGS_MODULE=tests.settings.imagemagick
# test_orientation skipped because of gh#jazzband/sorl-thumbnail#676
%pytest -rs -k "not ($skip_tests or test_orientation)"
export DJANGO_SETTINGS_MODULE=tests.settings.dbm
%pytest -rs -k "not ($skip_tests)"
export DJANGO_SETTINGS_MODULE=tests.settings.imagemagick
%pytest -rs -k "not ($skip_tests or test_templatetags)"
export DJANGO_SETTINGS_MODULE=tests.settings.wand
%pytest -rs -k "not ($skip_tests)"

# pgmagick is not installed in all environments
%{python_expand if [ -d %{$python_sitearch}/pgmagick/ ]; then
  export DJANGO_SETTINGS_MODULE=tests.settings.pgmagick
  $python -m pytest -rs -k "not ($skip_tests)"
fi
}

%{_sbindir}/redis-server &
export DJANGO_SETTINGS_MODULE=tests.settings.redis
%pytest -rs -k "not ($skip_tests)"
killall redis-server

%files %{python_files}
%doc AUTHORS.rst CHANGES.rst README.rst
%license LICENSE
%{python_sitelib}/sorl
%{python_sitelib}/sorl_thumbnail-%{version}.dist-info

%changelog
* Thu Nov  2 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 12.10.0:
  * Fixed safe_filter application on various thumbnail template tags.
  * Fixed slow performance with external storages like S3.
  * Added support for Django 4.2.
  * Drop support for Python 3.7.
  * Confirmed Python 3.11 support.
  * Drop support for Django 2.2 and 3.1.
  * Added support for Django 4.1.
  * Drop support for Python 3.6.
  * Fixed various Pillow deprecation warnings.
  * Drop support for Django 3.0.
  * Added support for Django 3.2 and 4.0.
  * Confirmed Python 3.9 and 3.10 support.
  * Adapted size regex getting size from the identify output.
  * Display possible ``thumbnail`` command labels in command help.
  * Added Jazzband code of conduct.
- Switch to pyproject macros.
- Kill redis-server when we're finished with it.
- Skip a truculent test.
* Wed Dec 21 2022 pgajdos@suse.com
- ImageMagick instead of GraphicsMagick
* Wed Jan 12 2022 John Vandenberg <jayvdb@gmail.com>
- Update tests to run on Django 4
- Disable boto related tests on Python 3.10 due to missing dependency
- Disable TestDescriptors tests on all test runs
* Wed Oct 13 2021 Matej Cepl <mcepl@suse.com>
- Skip test_orientation with
  DJANGO_SETTINGS_MODULE=tests.settings.imagemagick
  (gh#jazzband/sorl-thumbnail#676).
* Mon Mar  1 2021 John Vandenberg <jayvdb@gmail.com>
- Enable Wand tests
* Mon Feb 22 2021 John Vandenberg <jayvdb@gmail.com>
- Disable pgmagick tests on Tumbleweed Python 3.6 due to broken
  python36-pgmagick
* Tue Nov 24 2020 John Vandenberg <jayvdb@gmail.com>
- Require Python 3 & Django 2+, fixing builds on Leap 15.x
- Skip flaky test test_no_source_get_image which counts open file
  descriptors
- Update to v12.7.0
  * Drop support for Django 1.11
  * Added support for Django 3.1
  * Correction in convert_engine with unknown exif orientation
  * Using more resilient _get_exif_orientation logic in convert engine
  * Update wand_engine.py for ImageMagick 7
  * Fix cannot write mode RGBA as JPEG when thumbnailing a GIF
* Wed Sep  2 2020 Marketa Calabkova <mcalabkova@suse.com>
- Fix test execution
* Sun May 31 2020 John Vandenberg <jayvdb@gmail.com>
- Activated test suites
* Wed Apr  1 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v12.6.3
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Jan  3 2012 alexandre@exatati.com.br
- Update to 11.12:
  - Sorry, no changelog atm.
- Remove CFLAGS and %%clean section from spec file;
- License in SPDX format.
* Wed Sep 14 2011 alexandre@exatati.com.br
- Update to 11.09:
  - Sorry, no changelog.
* Fri Apr 29 2011 alexandre@exatati.com.br
- Update to 11.05.1:
  - Sorry, no changelog.
* Thu Apr 28 2011 alexandre@exatati.com.br
- Update to 11.05:
  - Sorry, no changelog.
* Wed Apr 20 2011 alexandre@exatati.com.br
- Update to 11.04:
- Regenerate spec file with py2pack.
* Sat Jan 29 2011 alexandre@exatati.com.br
- Update to 11.01;
- Spec file cleaned with spec-cleaner;
- Bzip2 source file.
* Sun Jun 20 2010 nix@opensuse.org
- Make wv a Recommends and change from wv2 to libwv2
* Mon Oct  5 2009 alexandre@exatati.com.br
- Update to 3.2.5;
- Building as noarch for openSUSE >= 11.2.
* Fri Sep 18 2009 alexandre@exatati.com.br
- Update to 3.2.4.
* Tue Sep 15 2009 alexandre@exatati.com.br
- Update to 3.2.3.
* Fri Aug 28 2009 alexandre@exatati.com.br
- Update to 3.2.2.
* Tue Aug 18 2009 alexandre@exatati.com.br
- Initial package (3.2) for openSUSE.
